@@ -29,7 +29,7 @@
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
-#define QGIS_QML_SUBDIR "qml"
+#define QGIS_QML_SUBDIR "lib/qt/qml"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -42,18 +42,18 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define PYTHON_VERSION "3.11.13"
+#define PYTHON_VERSION "3.13.7"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "11"
-#define PYTHON_VERSION_PATCH "13"
+#define PYTHON_VERSION_MINOR "13"
+#define PYTHON_VERSION_PATCH "7"
 
 #define PROJ_VERSION_MAJOR 9
 #define PROJ_VERSION_MINOR 6
-#define PROJ_VERSION_PATCH 2
+#define PROJ_VERSION_PATCH 0
 
 /* #undef USING_NMAKE */
 
-/* #undef USING_NINJA */
+#define USING_NINJA
 
 #define HAVE_GUI
 
@@ -67,12 +67,12 @@
 
 /* #undef SERVER_SKIP_ECW */
 
-/* #undef HAVE_SERVER_PYTHON_PLUGINS */
+#define HAVE_SERVER_PYTHON_PLUGINS
 
 #define HAVE_OAUTH2_PLUGIN
 
-/* #undef HAVE_OPENCL */
-/* #undef OPENCL_USE_NEW_HEADER */
+#define HAVE_OPENCL
+#define OPENCL_USE_NEW_HEADER
 
 /* #undef ENABLE_MODELTEST */
 
@@ -88,7 +88,7 @@
 
 /* #undef AGGRESSIVE_SAFE_MODE */
 
-/* #undef HAVE_QUICK */
+#define HAVE_QUICK
 
 #define HAVE_QTSERIALPORT
 
@@ -102,21 +102,21 @@
 
 #define HAVE_COPC
 
-/* #undef HAVE_PDAL_QGIS */
-#define PDAL_VERSION ""
-#define PDAL_VERSION_MAJOR_INT 
-#define PDAL_VERSION_MINOR_INT 
-#define PDAL_VERSION_MAJOR ""
-#define PDAL_VERSION_MINOR ""
-#define PDAL_VERSION_MICRO ""
+#define HAVE_PDAL_QGIS
+#define PDAL_VERSION "2.9.2"
+#define PDAL_VERSION_MAJOR_INT 2
+#define PDAL_VERSION_MINOR_INT 9
+#define PDAL_VERSION_MAJOR "2"
+#define PDAL_VERSION_MINOR "9"
+#define PDAL_VERSION_MICRO "2"
 
-/* #undef HAVE_DRACO */
+#define HAVE_DRACO
 
-/* #undef ENABLE_TESTS */
+#define ENABLE_TESTS
 
-/* #undef HAS_KDE_QT5_PDF_TRANSFORM_FIX */
-/* #undef HAS_KDE_QT5_SMALL_CAPS_FIX */
-/* #undef HAS_KDE_QT5_FONT_STRETCH_FIX */
+#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
+#define HAS_KDE_QT5_SMALL_CAPS_FIX
+#define HAS_KDE_QT5_FONT_STRETCH_FIX
 
 /* #undef HAVE_PDF4QT */
 
