@@ -48,6 +48,7 @@ from qgis.core import (
     QgsProcessingContext,
     QgsProcessingUtils,
     QgsProcessingFeedback,
+    QgsProperty,
 )
 from qgis.analysis import QgsNativeAlgorithms
 from qgis.testing import _UnexpectedSuccess, QgisTestCase, start_app
@@ -287,10 +288,14 @@ class AlgorithmsTest:
                 tmp = ""
                 for r in param["name"].split("::|::"):
                     v = r.split("::~::")
-                    tmp += "{}::~::{}::~::{}::~::{};".format(
+                    tmp += "{}::~::{}::~::{}::~::{}::|::".format(
                         os.path.join(prefix, v[0]), v[1], v[2], v[3]
                     )
-                return tmp[:-1]
+                # trim final separator ::|::
+                return tmp[:-5]
+            elif param["type"] == "property":
+                if param.get("expression"):
+                    return QgsProperty.fromExpression(param["expression"])
         except TypeError:
             # No type specified, use whatever is there
             return param
@@ -554,6 +559,142 @@ class GenericAlgorithmsTest(QgisTestCase):
         # check that calling helpUrl() works without error
         alg.helpUrl()
 
+        if alg.provider().id() in ("qgis", "native", "3d", "pdal"):
+            if alg.id() not in (
+                "native:exportmeshedges",
+                "native:exportmeshfaces",
+                "native:exportmeshongrid",
+                "native:exportmeshvertices",
+                "native:intersection",
+                "native:meshcontours",
+                "native:meshexportcrosssection",
+                "native:meshexporttimeseries",
+                "native:meshrasterize",
+                "native:surfacetopolygon",
+                "qgis:advancedpythonfieldcalculator",
+                "qgis:barplot",
+                "qgis:boxplot",
+                "qgis:distancematrix",
+                "qgis:distancetonearesthublinetohub",
+                "qgis:distancetonearesthubpoints",
+                "qgis:eliminateselectedpolygons",
+                "qgis:executesql",
+                "qgis:generatepointspixelcentroidsalongline",
+                "qgis:hypsometriccurves",
+                "qgis:idwinterpolation",
+                "qgis:knearestconcavehull",
+                "qgis:listuniquevalues",
+                "qgis:meanandstandarddeviationplot",
+                "qgis:pointsdisplacement",
+                "qgis:polarplot",
+                "qgis:randomextractwithinsubsets",
+                "qgis:randompointsalongline",
+                "qgis:randompointsinlayerbounds",
+                "qgis:randompointsinsidepolygons",
+                "qgis:randomselection",
+                "qgis:randomselectionwithinsubsets",
+                "qgis:rastercalculator",
+                "qgis:rasterlayerhistogram",
+                "qgis:rectanglesovalsdiamondsvariable",
+                "qgis:regularpoints",
+                "qgis:relief",
+                "qgis:scatter3dplot",
+                "qgis:selectbyexpression",
+                "qgis:setstyleforrasterlayer",
+                "qgis:setstyleforvectorlayer",
+                "qgis:texttofloat",
+                "qgis:tininterpolation",
+                "qgis:variabledistancebuffer",
+                "qgis:vectorlayerhistogram",
+                "qgis:vectorlayerscatterplot",
+            ):
+                self.assertTrue(
+                    alg.tags(),
+                    f"Algorithm {alg.id()} has no tags!",
+                )
+
+            if alg.id() not in ("qgis:rectanglesovalsdiamondsvariable",):
+                self.assertTrue(
+                    alg.shortHelpString(),
+                    f"Algorithm {alg.id()} has no shortHelpString!",
+                )
+
+            if alg.id() not in (
+                "native:createspatialindex",
+                "native:tilesxyzdirectory",
+                "native:tilesxyzmbtiles",
+                "pdal:assignprojection",
+                "pdal:boundary",
+                "pdal:clip",
+                "pdal:convertformat",
+                "pdal:createcopc",
+                "pdal:density",
+                "pdal:exportraster",
+                "pdal:exportrastertin",
+                "pdal:exportvector",
+                "pdal:filter",
+                "pdal:info",
+                "pdal:merge",
+                "pdal:reproject",
+                "pdal:thinbydecimate",
+                "pdal:thinbyradius",
+                "pdal:tile",
+                "pdal:virtualpointcloud",
+                "qgis:advancedpythonfieldcalculator",
+                "qgis:distancematrix",
+                "qgis:distancetonearesthublinetohub",
+                "qgis:distancetonearesthubpoints",
+                "qgis:eliminateselectedpolygons",
+                "qgis:executesql",
+                "qgis:generatepointspixelcentroidsalongline",
+                "qgis:hypsometriccurves",
+                "qgis:linestopolygons",
+                "qgis:listuniquevalues",
+                "qgis:minimumboundinggeometry",
+                "qgis:pointsdisplacement",
+                "qgis:randomextractwithinsubsets",
+                "qgis:randompointsalongline",
+                "qgis:randompointsinlayerbounds",
+                "qgis:randompointsinsidepolygons",
+                "qgis:rastercalculator",
+                "qgis:rectanglesovalsdiamondsvariable",
+                "qgis:regularpoints",
+                "qgis:relief",
+                "qgis:setstyleforrasterlayer",
+                "qgis:setstyleforvectorlayer",
+                "qgis:statisticsbycategories",
+                "qgis:variabledistancebuffer",
+            ):
+                self.assertTrue(
+                    alg.shortDescription(),
+                    f"Algorithm {alg.id()} has not shortDescription!",
+                )
+            if alg.shortDescription():
+                self.assertTrue(
+                    alg.shortDescription()[0].isupper(),
+                    f'Algorithm {alg.id()} shortDescription does not start with capital! "{alg.shortDescription()}"',
+                )
+                self.assertEqual(
+                    alg.shortDescription()[-1],
+                    ".",
+                    f'Algorithm {alg.id()} shortDescription does not end with full stop "{alg.shortDescription()}"',
+                )
+                self.assertFalse(
+                    alg.shortDescription().lower().startswith("this algorithm"),
+                    f'Algorithm {alg.id()} shortDescription should NOT start with eg "This algorithm computes...", just use "Computes..." instead: "{alg.shortDescription()}"',
+                )
+                first_word = alg.shortDescription().split(" ")[0].lower()
+                if first_word not in ("randomly",):
+                    self.assertEqual(
+                        first_word[-1],
+                        "s",
+                        f'Algorithm {alg.id()} shortDescription should start with a verb ending in s, eg "Combines", "Creates",... "{alg.shortDescription()}"',
+                    )
+                self.assertFalse(
+                    "</" in alg.shortDescription(),
+                    f'Algorithm {alg.id()} shortDescription should not contain any HTML formatting "{alg.shortDescription()}"',
+                )
+
 
 if __name__ == "__main__":
     nose2.main()
